==> developer-center-api-3.1.2-20180814.121054-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/AppManagerDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by sty on 2017/5/16.
 */
public class AppManagerDto implements Serializable {

    private static final long serialVersionUID = 7080886473200071618L;

    private Long id;
    private Boolean enabled;
    private String appName;
    private Long developerId;
    private String email;
    private Date gmtCreateDate;
    private Long appSwitch;


    private Boolean usedSource;//是否使用源码

    private Integer rate;//使用源码比例

    private Boolean openCodeEdit;//开启代码编辑

    private Boolean showAlarm;//展示警示

    private Integer appTradingCount;//今日兑换次数

    private Integer appTradingLevel;//兑换等级

    /**
     * 是否具有开发能力
     */
    private Integer developAbility;

    /**
     * 判断App的开关状态
     * @param boundType
     * @return
     */
    public boolean isAppSwitch(int boundType) {
        long v = 1 << boundType;
        long ret = appSwitch & v;
        return ret != 0;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Boolean getEnabled() {
        return enabled;
    }

    public void setEnabled(Boolean enabled) {
        this.enabled = enabled;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Long getDeveloperId() {
        return developerId;
    }

    public void setDeveloperId(Long developerId) {
        this.developerId = developerId;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public Date getGmtCreateDate() {
        return gmtCreateDate;
    }

    public void setGmtCreateDate(Date gmtCreateDate) {
        this.gmtCreateDate = gmtCreateDate;
    }

    public Long getAppSwitch() {
        return appSwitch;
    }

    public void setAppSwitch(Long appSwitch) {
        this.appSwitch = appSwitch;
    }

    public Boolean getUsedSource() {
        return usedSource;
    }

    public void setUsedSource(Boolean usedSource) {
        this.usedSource = usedSource;
    }

    public Integer getRate() {
        return rate;
    }

    public void setRate(Integer rate) {
        this.rate = rate;
    }

    public Boolean getOpenCodeEdit() {
        return openCodeEdit;
    }

    public void setOpenCodeEdit(Boolean openCodeEdit) {
        this.openCodeEdit = openCodeEdit;
    }

    public Boolean getShowAlarm() {
        return showAlarm;
    }

    public void setShowAlarm(Boolean showAlarm) {
        this.showAlarm = showAlarm;
    }

    public Integer getAppTradingCount() {
        return appTradingCount;
    }

    public void setAppTradingCount(Integer appTradingCount) {
        this.appTradingCount = appTradingCount;
    }

    public Integer getAppTradingLevel() {
        return appTradingLevel;
    }

    public void setAppTradingLevel(Integer appTradingLevel) {
        this.appTradingLevel = appTradingLevel;
    }

    public Integer getDevelopAbility() {
        return developAbility;
    }

    public void setDevelopAbility(Integer developAbility) {
        this.developAbility = developAbility;
    }
}

==> developer-center-api-3.3.15-dev-sources.jar: cn/com/duiba/developer/center/api/domain/dto/AppManagerDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by sty on 2017/5/16.
 */
public class AppManagerDto implements Serializable {

    private static final long serialVersionUID = 7080886473200071618L;

    private Long id;
    private Boolean enabled;
    private String appName;
    private Long developerId;
    private String email;
    private Date gmtCreateDate;
    private Long appSwitch;
    private String phone;


    private Boolean usedSource;//是否使用源码

    private Integer rate;//使用源码比例

    private Boolean openCodeEdit;//开启代码编辑

    private Boolean showAlarm;//展示警示

    private Integer appTradingCount;//今日兑换次数

    private Integer appTradingLevel;//兑换等级

    /**
     * 是否具有开发能力
     */
    private Integer developAbility;

    /**
     * 判断App的开关状态
     * @param boundType
     * @return
     */
    public boolean isAppSwitch(int boundType) {
        long v = 1 << boundType;
        long ret = appSwitch & v;
        return ret != 0;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Boolean getEnabled() {
        return enabled;
    }

    public void setEnabled(Boolean enabled) {
        this.enabled = enabled;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Long getDeveloperId() {
        return developerId;
    }

    public void setDeveloperId(Long developerId) {
        this.developerId = developerId;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public Date getGmtCreateDate() {
        return gmtCreateDate;
    }

    public void setGmtCreateDate(Date gmtCreateDate) {
        this.gmtCreateDate = gmtCreateDate;
    }

    public Long getAppSwitch() {
        return appSwitch;
    }

    public void setAppSwitch(Long appSwitch) {
        this.appSwitch = appSwitch;
    }

    public Boolean getUsedSource() {
        return usedSource;
    }

    public void setUsedSource(Boolean usedSource) {
        this.usedSource = usedSource;
    }

    public Integer getRate() {
        return rate;
    }

    public void setRate(Integer rate) {
        this.rate = rate;
    }

    public Boolean getOpenCodeEdit() {
        return openCodeEdit;
    }

    public void setOpenCodeEdit(Boolean openCodeEdit) {
        this.openCodeEdit = openCodeEdit;
    }

    public Boolean getShowAlarm() {
        return showAlarm;
    }

    public void setShowAlarm(Boolean showAlarm) {
        this.showAlarm = showAlarm;
    }

    public Integer getAppTradingCount() {
        return appTradingCount;
    }

    public void setAppTradingCount(Integer appTradingCount) {
        this.appTradingCount = appTradingCount;
    }

    public Integer getAppTradingLevel() {
        return appTradingLevel;
    }

    public void setAppTradingLevel(Integer appTradingLevel) {
        this.appTradingLevel = appTradingLevel;
    }

    public Integer getDevelopAbility() {
        return developAbility;
    }

    public void setDevelopAbility(Integer developAbility) {
        this.developAbility = developAbility;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
}
